@@ -35,6 +35,7 @@
 #'be created from pseudo-documents which are obtained by virtually splitting each documents into
 #'chunks of the length \code{window_size} by going with sliding window through them.
 #'This is useful for creating special statistics which are used for coherence estimation in topic models.
+#'@param ... placeholder for additional arguments (not used at the moment).
 #'@return \code{text2vec_vocabulary} object, which is actually a \code{data.frame}
 #'  with following columns:
 #'  \item{\code{term}       }{ \code{character} vector of unique terms}
@@ -58,7 +59,7 @@
 #' doc_proportion_min = 0.001, vocab_term_max = 20000)
 #'@export
 create_vocabulary = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
-                       stopwords = character(0), sep_ngram = "_", window_size = 0L) {
+                       stopwords = character(0), sep_ngram = "_", window_size = 0L, ...) {
   stopifnot(is.numeric(ngram) && length(ngram) == 2 && ngram[[2]] >= ngram[[1]])
   stopifnot(is.character(stopwords))
   stopifnot(is.character(sep_ngram) && nchar(sep_ngram) == 1L)
@@ -71,16 +72,16 @@ create_vocabulary = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
 #' @rdname create_vocabulary
 #' @export
 vocabulary = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
-                       stopwords = character(0), sep_ngram = "_", window_size = 0L) {
+                       stopwords = character(0), sep_ngram = "_", window_size = 0L, ...) {
   .Deprecated("create_vocabulary")
-  create_vocabulary(it, ngram, stopwords, sep_ngram, window_size)
+  create_vocabulary(it, ngram, stopwords, sep_ngram, window_size, ...)
 }
 #' @describeIn create_vocabulary creates \code{text2vec_vocabulary} from predefined
 #' character vector. Terms will be inserted \bold{as is}, without any checks
 #' (ngrams number, ngram delimiters, etc.).
 #' @export
 create_vocabulary.character = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
-                                 stopwords = character(0), sep_ngram = "_", window_size = 0L) {
+                                 stopwords = character(0), sep_ngram = "_", window_size = 0L, ...) {
 
   ngram_min = as.integer( ngram[[1]] )
   ngram_max = as.integer( ngram[[2]] )
@@ -117,7 +118,7 @@ vocabulary_insert_document_batch_generic = function(ptr, x) {
 #' @describeIn create_vocabulary collects unique terms and corresponding statistics from object.
 #' @export
 create_vocabulary.itoken = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
-                              stopwords = character(0), sep_ngram = "_", window_size = 0L) {
+                              stopwords = character(0), sep_ngram = "_", window_size = 0L, ...) {
   if (inherits(it, "R6"))
     it = it$clone(deep = TRUE)
   else {
@@ -152,7 +153,6 @@ create_vocabulary.itoken = function(it, ngram = c("ngram_min" = 1L, "ngram_max"
 
 #' @describeIn create_vocabulary collects unique terms and corresponding
 #'   statistics from iterator.
-#' @param ... placeholder for additional arguments (not used at the moment).
 #' @export
 create_vocabulary.itoken_parallel = function(it, ngram = c("ngram_min" = 1L, "ngram_max" = 1L),
                                   stopwords = character(0), sep_ngram = "_", window_size = 0L, ...) {
@@ -305,6 +305,10 @@ detect_ngrams = function(vocab, ...) {
 
 
 #' @export
+#' @title Printing Vocabulary
+#' @description Print a vocabulary.
+#' @param x vocabulary
+#' @param ... optional arguments to print methods.
 #' @method print text2vec_vocabulary
 print.text2vec_vocabulary = function(x, ...) {
   m1 = paste("Number of docs:", attr(x, "document_count", TRUE))
